@@ -877,8 +877,10 @@ sub www_ajaxPrices {
         } || 0,
 
         shipping => eval {
-            die unless $shipping;
-            $self->update({ shippingAddressId => $shipping });
+            #die unless $shipping;
+            if ( $shipping ) {
+                $self->update({ shippingAddressId => $shipping });
+            }
             my $ship = WebGUI::Shop::Ship->new($self->session);
             $ship->getOptions($self);
         } || [],
@@ -1174,7 +1176,13 @@ sub www_view {
 
         my $billingAddressId = $self->get('billingAddressId');
         if ($billingAddressId) {
-            $billingAddressOptions{'update_address'} = sprintf $i18n->get('Update %s'), $self->getBillingAddress->get('label');
+            my $billingAddress = eval { $self->getBillingAddress };
+            if ( defined $billingAddress ) {
+                $billingAddressOptions{'update_address'} = sprintf $i18n->get('Update %s'), $billingAddress->get('label');
+            }
+            elsif (my $e = WebGUI::Error->caught("WebGUI::Error::ObjectNotFound") && $self->get('billingAddressId')) {
+                $self->update({billingAddressId=>''});
+            }
         }
 
         %billingAddressOptions = (%billingAddressOptions, %addressOptions);
@@ -1190,7 +1198,10 @@ sub www_view {
 
         my $shippingAddressId = $self->get('shippingAddressId');
         if ($shippingAddressId) {
-            $shippingAddressOptions{'update_address'} = sprintf $i18n->get('Update %s'), $self->getShippingAddress->get('label');
+            my $shippingAddress = eval { $self->getShippingAddress };
+            if ( defined $shippingAddress ) {
+               $shippingAddressOptions{'update_address'} = sprintf $i18n->get('Update %s'), $shippingAddress->get('label');
+            }
         }
         %shippingAddressOptions = (%shippingAddressOptions, %addressOptions);
 
@@ -1249,14 +1260,6 @@ sub www_view {
 
     # render the cart
     my $template = WebGUI::Asset::Template->new($session, $session->setting->get("shopCartTemplateId"));
-
-    my $style = $session->style;
-    my $yui = $url->extras('/yui/build');
-    $style->setScript("$yui/yahoo-dom-event/yahoo-dom-event.js");
-    $style->setScript("$yui/json/json-min.js");
-    $style->setScript("$yui/connection/connection-min.js");
-    $style->setScript($url->extras('underscore/underscore-min.js'));
-    $style->setScript($url->extras('shop/cart.js'), undef, 1);
     return $session->style->userStyle($template->process(\%var));
 }
 
